import { queryMandate } from '@/services/SmartOps';
import { useRequest } from '@umijs/max';
import {
  Button,
  Col,
  ConfigProvider,
  Divider,
  Form,
  Input,
  Modal,
  Row,
  Select,
  Table,
  message,
} from 'antd';
import dayjs from 'dayjs';
import { useEffect, useState } from 'react';
import styles from '../Popup/index.less';
import {
  MandateClass,
  MandateStatus,
  MandateType,
  OrderStatus,
  OrderType,
  ignoreReason,
} from '../constent';

import zhCN from 'antd/es/locale/zh_CN';

const MandateDetail = (props) => {
  const { projectID, mandateID, userList } = props;
  const [mandateDetail, setMandateDetail] = useState();
  const [mandateChild, setMandateChild] = useState([]);
  const [handledWorkOrder, setHandledWorkOrder] = useState([]);

  const [ignoreModalOpen, setIgnoreModalOpen] = useState(false);
  const [autoHandleModalOpen, setAutoHandleModalOpen] = useState(false);
  const [dispatchModalOpen, setDispatchModalOpen] = useState(false);

  const columns = [
    {
      title: '参数',
      dataIndex: 'Title',
    },
    {
      title: '调整内容',
      dataIndex: 'Content',
    },
  ];

  const { run: getMandateInfo } = useRequest(queryMandate, {
    manual: true,
    formatResult: (result) => {
      if (result?.data) {
        const tempMandate = {
          ...result.data,
          Status: MandateStatus.find(
            (item) => item.value === result.data.Status,
          ),
          MandateClass: MandateClass.find(
            (item) => item.value === result.data.MandateClass,
          ),
          MandateType: MandateType.find(
            (item) => item.value === result.data.MandateType,
          ),
          ResponsiblePeople: userList.find(
            (item) => item.ID === result.data.ResponsiblePeople,
          ),
          CreateTime: dayjs(result.data.CreateTime).format('YYYY-MM-DD HH:mm'),
        };
        const workOrder = result.data.Records.map((item) => {
          return {
            ...item,
            CreateTime: dayjs(item.CreateTime).format('YYYY-MM-DD HH:mm'),
            Status: OrderStatus.find((status) => status.value === item.Status),
            RecordType: OrderType.find(
              (type) => type.value === item.RecordType,
            ),
            Responsible: userList.find((user) => user.ID === item.Responsible),
          };
        });
        setMandateDetail(tempMandate);
        setMandateChild(tempMandate.MandateChild);
        setHandledWorkOrder(workOrder);
      }
    },
  });

  const onIgnoreClick = () => {
    setIgnoreModalOpen(true);
  };

  const onDispatchClick = () => {
    setDispatchModalOpen(true);
  };

  const onAutoHandleClick = () => {
    setAutoHandleModalOpen(true);
  };

  const onManualHandleClick = () => {
    console.log('manual handle click');
  };

  const onIgnoreConfirm = (text) => {
    console.log(text);
    // 调用ignore
    setIgnoreModalOpen(false);
  };

  const onAutoHandleConfirm = (text) => {
    console.log(text);
    setAutoHandleModalOpen(false);
  };

  const onManualHandleConfirm = () => {
    console.log('manual handle Confirm');
  };

  const onDispatchConfirm = () => {
    console.log('ignore Confirm');
    setDispatchModalOpen(false);
  };

  useEffect(() => {
    getMandateInfo({ mandate_id: mandateID });
  }, []);

  return (
    <div>
      <div className={styles.mandate}>
        <Row>
          <Col className={styles.fontS24} span={4}>
            任务内容：{' '}
          </Col>
          <Col className={styles.fontS24} span={20}>
            <Table
              columns={columns}
              dataSource={mandateChild}
              pagination={false}
            />
          </Col>
        </Row>
        <Row>
          <Col className={styles.fontS24} span={14}>
            任务时间：{mandateDetail?.CreateTime || '-'}
          </Col>
          <Col className={styles.fontS24}>
            任务类别：{mandateDetail?.MandateClass.label || '-'}
          </Col>
        </Row>
        <Row>
          <Col className={styles.fontS24} span={14}>
            任务状态：{' '}
            <span style={{ color: ' #5697e4' }}>
              {mandateDetail?.Status.label}
            </span>
          </Col>
          <Col className={styles.fontS24}>
            任务负责人：{mandateDetail?.ResponsiblePeople?.CName || '-'}
          </Col>
        </Row>
      </div>
      {handledWorkOrder?.length > 0 && <Divider />}
      {handledWorkOrder?.map((item) => {
        return (
          <div key={item.Id} className={styles.relatedOrder}>
            <div className={styles.leftInfo}>
              <Row>
                <Col span={12} className={styles.fontS24}>
                  工单类型：{item?.RecordType?.label}
                </Col>
                <Col className={styles.fontS24}>时间：{item?.CreateTime}</Col>
              </Row>
              <Row>
                <Col span={12} className={styles.fontS24}>
                  工单状态：
                  <span style={{ color: ' #5697e4' }}>
                    {item?.Status?.label}
                  </span>
                </Col>
                <Col className={styles.fontS24}>
                  工单负责人：{item?.Responsible?.CName}
                </Col>
              </Row>
            </div>
            <Divider type="vertical" style={{ height: '40px' }} />
            <div className={styles.rightButton}>查看工单</div>
          </div>
        );
      })}
      {mandateDetail?.Status?.value === 0 && <Divider />}
      {mandateDetail?.Status?.value === 0 && (
        <div className={styles.footerConstainer}>
          <Button
            className={styles.footerBtn}
            shape="round"
            onClick={onIgnoreClick}
          >
            忽略
          </Button>
          <Button
            className={styles.footerBtn}
            shape="round"
            onClick={onManualHandleClick}
          >
            手动处理
          </Button>
          <Button
            className={styles.footerBtn}
            shape="round"
            onClick={onAutoHandleClick}
          >
            自动处理
          </Button>
          <Button
            className={styles.footerBtn}
            shape="round"
            onClick={onDispatchClick}
          >
            派单
          </Button>
        </div>
      )}
      <ConfigProvider locale={zhCN}>
        <IgnoreTaskModal
          open={ignoreModalOpen}
          onCancel={() => setIgnoreModalOpen(false)}
          onOk={onIgnoreConfirm}
        />
        <AutoHandleModal
          open={autoHandleModalOpen}
          onCancel={() => setAutoHandleModalOpen(false)}
          onOk={onAutoHandleConfirm}
        />
        <DispatchModa
          open={dispatchModalOpen}
          onCancel={() => setDispatchModalOpen(false)}
          onOk={onDispatchConfirm}
        />
      </ConfigProvider>
    </div>
  );
};

export default MandateDetail;

const IgnoreTaskModal = (params) => {
  const { open, onCancel, onOk } = params;

  const [ignoreReasonText, setIgnoreReasonText] = useState('');
  const [selectedReason, setSelectedReason] = useState({});
  const [showInput, setShowInput] = useState(false);

  const onReasonChange = (reason, option) => {
    if (reason !== 4) {
      setSelectedReason(option);
      setShowInput(false);
    } else {
      setShowInput(true);
    }
  };

  const onReasonTextChange = (e) => {
    setIgnoreReasonText(e.target.value);
  };

  const confirmIgnore = () => {
    if (showInput) {
      if (!ignoreReasonText.length) {
        message.warning('请输入忽略理由');
      } else {
        onOk(ignoreReasonText);
      }
    } else {
      if (selectedReason?.label) {
        onOk(selectedReason.label);
      } else {
        message.warning('请选择忽略理由');
      }
    }
  };

  return (
    <Modal
      title="忽略"
      open={open}
      onCancel={onCancel}
      onOk={confirmIgnore}
      destroyOnClose
    >
      <div style={{ padding: '15px' }}>
        <Form layout="vertical">
          <Form.Item label="忽略理由:">
            <Select
              className={styles.fontS24}
              options={ignoreReason}
              onChange={onReasonChange}
              allowClear
            />
          </Form.Item>
          {showInput && (
            <Form.Item label="输入理由:">
              <Input placeholder="请输入理由" onChange={onReasonTextChange} />
            </Form.Item>
          )}
        </Form>
      </div>
    </Modal>
  );
};

const AutoHandleModal = (props) => {
  const { open, onCancel, onOk } = props;

  const [automation, setAutomation] = useState('');

  const confirmAutoHandle = () => {
    if (automation.length) {
      onOk(automation);
    } else {
      message.warning('请输入口令');
    }
  };

  return (
    <Modal
      title="自动处理"
      open={open}
      onCancel={onCancel}
      onOk={confirmAutoHandle}
      destroyOnClose
    >
      <div style={{ padding: '15px' }}>
        <Form layout="vertical">
          <Form.Item label="口令:">
            {
              <Input
                placeholder="请输入口令"
                onChange={(e) => {
                  setAutomation(e.target.value);
                }}
              />
            }
          </Form.Item>
        </Form>
      </div>
    </Modal>
  );
};

const DispatchModa = (props) => {
  const { open, onCancel } = props;
  return (
    <Modal title="工单派遣" open={open} onCancel={onCancel}>
      派单
    </Modal>
  );
};
